@@ -4,6 +4,7 @@ from typing import List
 import pytest
 from tensorzero import (
     AsyncTensorZeroGateway,
+    DiclOptimizationConfig,
     FireworksSFTConfig,
     OpenAISFTConfig,
     OptimizationJobStatus,
@@ -13,6 +14,35 @@ from tensorzero import (
 )
 
 
+def test_sync_dicl(
+    embedded_sync_client: TensorZeroGateway,
+    mixed_rendered_samples: List[RenderedSample],
+):
+    optimization_config = DiclOptimizationConfig(
+        embedding_model="text-embedding-3-small",
+        variant_name="test_dicl",
+        function_name="basic_test",
+        dimensions=None,
+        batch_size=None,
+        max_concurrency=None,
+        k=None,
+        model=None,
+        credentials=None,
+    )
+    optimization_job_handle = embedded_sync_client.experimental_launch_optimization(
+        train_samples=mixed_rendered_samples,
+        val_samples=None,
+        optimization_config=optimization_config,
+    )
+    while True:
+        job_info = embedded_sync_client.experimental_poll_optimization(
+            job_handle=optimization_job_handle
+        )
+        if job_info.status == OptimizationJobStatus.Completed:
+            break
+        sleep(1)
+
+
 def test_sync_openai_sft(
     embedded_sync_client: TensorZeroGateway,
     mixed_rendered_samples: List[RenderedSample],
@@ -65,6 +95,9 @@ def test_sync_together_sft(
     optimization_config = TogetherSFTConfig(
         model="meta-llama/Meta-Llama-3.1-8B-Instruct-Reference",
         api_base="http://localhost:3030/together/",
+        n_epochs=1,
+        training_type={"type": "Lora", "lora_r": 8, "lora_alpha": 16},
+        batch_size="max",
     )
     optimization_job_handle = embedded_sync_client.experimental_launch_optimization(
         train_samples=mixed_rendered_samples,
@@ -80,6 +113,38 @@ def test_sync_together_sft(
         sleep(1)
 
 
+@pytest.mark.asyncio
+async def test_async_dicl(
+    embedded_async_client: AsyncTensorZeroGateway,
+    mixed_rendered_samples: List[RenderedSample],
+):
+    optimization_config = DiclOptimizationConfig(
+        embedding_model="text-embedding-3-small",
+        variant_name="test_dicl",
+        function_name="basic_test",
+        dimensions=None,
+        batch_size=None,
+        max_concurrency=None,
+        k=None,
+        model=None,
+        credentials=None,
+    )
+    optimization_job_handle = (
+        await embedded_async_client.experimental_launch_optimization(
+            train_samples=mixed_rendered_samples,
+            val_samples=None,
+            optimization_config=optimization_config,
+        )
+    )
+    while True:
+        job_info = await embedded_async_client.experimental_poll_optimization(
+            job_handle=optimization_job_handle
+        )
+        if job_info.status == OptimizationJobStatus.Completed:
+            break
+        sleep(1)
+
+
 @pytest.mark.asyncio
 async def test_async_openai_sft(
     embedded_async_client: AsyncTensorZeroGateway,
@@ -138,6 +203,9 @@ async def test_async_together_sft(
     optimization_config = TogetherSFTConfig(
         model="meta-llama/Meta-Llama-3.1-8B-Instruct-Reference",
         api_base="http://localhost:3030/together/",
+        n_epochs=1,
+        training_type={"type": "Lora", "lora_r": 8, "lora_alpha": 16},
+        batch_size="max",
     )
     optimization_job_handle = (
         await embedded_async_client.experimental_launch_optimization(
