@@ -4,6 +4,7 @@ use reqwest::multipart::Form;
 use reqwest::multipart::Part;
 use reqwest::Client;
 use secrecy::{ExposeSecret, SecretString};
+use serde::de::DeserializeOwned;
 use serde::Deserialize;
 use serde::Serialize;
 use std::borrow::Cow;
@@ -80,6 +81,7 @@ pub enum TableName {
     FloatMetricFeedback,
     DemonstrationFeedback,
     CommentFeedback,
+    StaticEvaluationHumanFeedback,
 }
 
 impl TableName {
@@ -99,6 +101,7 @@ impl TableName {
             TableName::FloatMetricFeedback => "FloatMetricFeedback",
             TableName::DemonstrationFeedback => "DemonstrationFeedback",
             TableName::CommentFeedback => "CommentFeedback",
+            TableName::StaticEvaluationHumanFeedback => "StaticEvaluationHumanFeedback",
         }
     }
 }
@@ -422,6 +425,7 @@ impl ClickHouseConnectionInfo {
         }
     }
 
+    // TODO: deprecate this
     pub async fn run_query_synchronous_no_params(
         &self,
         query: String,
@@ -429,6 +433,20 @@ impl ClickHouseConnectionInfo {
         self.run_query_synchronous(query, &HashMap::default()).await
     }
 
+    pub async fn run_query_synchronous_no_params_de<T>(&self, query: String) -> Result<T, Error>
+    where
+        T: DeserializeOwned,
+    {
+        let result = self
+            .run_query_synchronous(query, &HashMap::default())
+            .await?;
+        serde_json::from_str(&result.response).map_err(|e| {
+            Error::new(ErrorDetails::ClickHouseDeserialization {
+                message: e.to_string(),
+            })
+        })
+    }
+
     /// Sometimes you might want to treat the data you're sending as a table if you're going
     /// to do some analysis or filtering prior to inserting it into ClickHouse.
     /// This function allows you to do this with ClickHouse's external data feature.
