@@ -9,6 +9,8 @@ use crate::cache::{
 use crate::config::{ProviderTypesConfig, TimeoutsConfig};
 use crate::endpoints::inference::InferenceClients;
 use crate::inference::types::extra_body::ExtraBodyConfig;
+use crate::inference::types::RequestMessagesOrBatch;
+use crate::inference::types::{ContentBlock, Text};
 use crate::model::{ModelProviderRequestInfo, UninitializedProviderConfig};
 use crate::model_table::BaseModelTable;
 use crate::model_table::ShorthandModelConfig;
@@ -377,10 +379,12 @@ impl TryFrom<EmbeddingResponseWithMetadata> for ModelInferenceResponseWithMetada
             output: vec![],
             created: response.created,
             system: None,
-            input_messages: vec![RequestMessage {
+            input_messages: RequestMessagesOrBatch::Message(vec![RequestMessage {
                 role: Role::User,
-                content: vec![input.clone().into()],
-            }], // TODO (#399): Store this information in a more appropriate way for this kind of request
+                content: vec![ContentBlock::Text(Text {
+                    text: input.clone(),
+                })],
+            }]), // TODO (#399): Store this information in a more appropriate way for this kind of request
             raw_request: response.raw_request,
             raw_response: response.raw_response,
             usage: response.usage,
