@@ -107,7 +107,7 @@ pub async fn launch_optimization_workflow(
         .await?;
     let variants = HashMap::from([(function_name.clone(), template_variant_name.clone())]);
     // Template the inferences and fetch any network resources needed
-    let rendered_inferences = render_samples(config, stored_inferences, variants).await?;
+    let rendered_inferences = render_samples(config.clone(), stored_inferences, variants).await?;
 
     // Drop any examples with output that is None
     let rendered_inferences = rendered_inferences
@@ -127,6 +127,8 @@ pub async fn launch_optimization_workflow(
             train_examples,
             val_examples,
             &InferenceCredentials::default(),
+            clickhouse_connection_info,
+            &config,
         )
         .await
 }
@@ -148,6 +150,8 @@ pub struct LaunchOptimizationParams {
 pub async fn launch_optimization(
     http_client: &reqwest::Client,
     params: LaunchOptimizationParams,
+    clickhouse_connection_info: &ClickHouseConnectionInfo,
+    config: Arc<Config>,
     // For the TODO above: will need to pass config in here
 ) -> Result<OptimizationJobHandle, Error> {
     let LaunchOptimizationParams {
@@ -162,6 +166,8 @@ pub async fn launch_optimization(
             train_examples,
             val_examples,
             &InferenceCredentials::default(),
+            clickhouse_connection_info,
+            &config,
         )
         .await
 }
