@@ -8,9 +8,14 @@ use pyo3::prelude::*;
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
 
+use crate::config::Config;
+use crate::db::clickhouse::ClickHouseConnectionInfo;
 use crate::endpoints::inference::InferenceCredentials;
 use crate::error::{Error, ErrorDetails};
 use crate::model::UninitializedModelConfig;
+use crate::optimization::dicl::{
+    DiclOptimizationConfig, DiclOptimizationJobHandle, UninitializedDiclOptimizationConfig,
+};
 use crate::optimization::fireworks_sft::{
     FireworksSFTConfig, FireworksSFTJobHandle, UninitializedFireworksSFTConfig,
 };
@@ -25,6 +30,7 @@ use crate::optimization::together_sft::{
 };
 use crate::stored_inference::RenderedSample;
 
+pub mod dicl;
 pub mod fireworks_sft;
 pub mod gcp_vertex_gemini_sft;
 pub mod openai_sft;
@@ -49,10 +55,11 @@ impl OptimizerInfo {
 #[cfg_attr(test, derive(ts_rs::TS))]
 #[cfg_attr(test, ts(export))]
 enum OptimizerConfig {
+    Dicl(DiclOptimizationConfig),
     OpenAISFT(OpenAISFTConfig),
     FireworksSFT(FireworksSFTConfig),
     GCPVertexGeminiSFT(Box<GCPVertexGeminiSFTConfig>),
-    TogetherSFT(TogetherSFTConfig),
+    TogetherSFT(Box<TogetherSFTConfig>),
 }
 
 #[cfg_attr(test, derive(ts_rs::TS))]
@@ -61,6 +68,8 @@ enum OptimizerConfig {
 #[cfg_attr(feature = "pyo3", pyclass(str))]
 #[serde(tag = "type", rename_all = "snake_case")]
 pub enum OptimizationJobHandle {
+    #[serde(rename = "dicl")]
+    Dicl(DiclOptimizationJobHandle),
     #[serde(rename = "openai_sft")]
     OpenAISFT(OpenAISFTJobHandle),
     #[serde(rename = "fireworks_sft")]
@@ -112,6 +121,7 @@ impl JobHandle for OptimizationJobHandle {
         credentials: &InferenceCredentials,
     ) -> Result<OptimizationJobInfo, Error> {
         match self {
+            OptimizationJobHandle::Dicl(job_handle) => job_handle.poll(client, credentials).await,
             OptimizationJobHandle::OpenAISFT(job_handle) => {
                 job_handle.poll(client, credentials).await
             }
@@ -131,7 +141,7 @@ impl JobHandle for OptimizationJobHandle {
 #[cfg_attr(test, derive(ts_rs::TS))]
 #[derive(Debug, Deserialize, Serialize)]
 #[cfg_attr(test, ts(export))]
-#[serde(tag = "type", rename_all = "snake_case")]
+#[serde(tag = "type", content = "content", rename_all = "snake_case")]
 pub enum OptimizerOutput {
     Variant(Box<UninitializedVariantConfig>),
     Model(UninitializedModelConfig),
@@ -252,6 +262,8 @@ pub trait Optimizer {
         train_examples: Vec<RenderedSample>,
         val_examples: Option<Vec<RenderedSample>>,
         credentials: &InferenceCredentials,
+        clickhouse_connection_info: &ClickHouseConnectionInfo,
+        config: &Config,
     ) -> Result<Self::Handle, Error>;
 }
 
@@ -263,22 +275,63 @@ impl Optimizer for OptimizerInfo {
         train_examples: Vec<RenderedSample>,
         val_examples: Option<Vec<RenderedSample>>,
         credentials: &InferenceCredentials,
+        clickhouse_connection_info: &ClickHouseConnectionInfo,
+        config: &Config,
     ) -> Result<Self::Handle, Error> {
         match &self.inner {
-            OptimizerConfig::OpenAISFT(config) => config
-                .launch(client, train_examples, val_examples, credentials)
+            OptimizerConfig::Dicl(optimizer_config) => optimizer_config
+                .launch(
+                    client,
+                    train_examples,
+                    val_examples,
+                    credentials,
+                    clickhouse_connection_info,
+                    config,
+                )
+                .await
+                .map(OptimizationJobHandle::Dicl),
+            OptimizerConfig::OpenAISFT(optimizer_config) => optimizer_config
+                .launch(
+                    client,
+                    train_examples,
+                    val_examples,
+                    credentials,
+                    clickhouse_connection_info,
+                    config,
+                )
                 .await
                 .map(OptimizationJobHandle::OpenAISFT),
-            OptimizerConfig::FireworksSFT(config) => config
-                .launch(client, train_examples, val_examples, credentials)
+            OptimizerConfig::FireworksSFT(optimizer_config) => optimizer_config
+                .launch(
+                    client,
+                    train_examples,
+                    val_examples,
+                    credentials,
+                    clickhouse_connection_info,
+                    config,
+                )
                 .await
                 .map(OptimizationJobHandle::FireworksSFT),
-            OptimizerConfig::GCPVertexGeminiSFT(config) => config
-                .launch(client, train_examples, val_examples, credentials)
+            OptimizerConfig::GCPVertexGeminiSFT(optimizer_config) => optimizer_config
+                .launch(
+                    client,
+                    train_examples,
+                    val_examples,
+                    credentials,
+                    clickhouse_connection_info,
+                    config,
+                )
                 .await
                 .map(OptimizationJobHandle::GCPVertexGeminiSFT),
-            OptimizerConfig::TogetherSFT(config) => config
-                .launch(client, train_examples, val_examples, credentials)
+            OptimizerConfig::TogetherSFT(optimizer_config) => optimizer_config
+                .launch(
+                    client,
+                    train_examples,
+                    val_examples,
+                    credentials,
+                    clickhouse_connection_info,
+                    config,
+                )
                 .await
                 .map(OptimizationJobHandle::TogetherSFT),
         }
@@ -306,6 +359,8 @@ impl UninitializedOptimizerInfo {
 #[cfg_attr(test, ts(export))]
 #[serde(tag = "type", rename_all = "snake_case")]
 pub enum UninitializedOptimizerConfig {
+    #[serde(rename = "dicl")]
+    Dicl(UninitializedDiclOptimizationConfig),
     #[serde(rename = "openai_sft")]
     OpenAISFT(UninitializedOpenAISFTConfig),
     #[serde(rename = "fireworks_sft")]
@@ -313,13 +368,14 @@ pub enum UninitializedOptimizerConfig {
     #[serde(rename = "gcp_vertex_gemini_sft")]
     GCPVertexGeminiSFT(UninitializedGCPVertexGeminiSFTConfig),
     #[serde(rename = "together_sft")]
-    TogetherSFT(UninitializedTogetherSFTConfig),
+    TogetherSFT(Box<UninitializedTogetherSFTConfig>),
 }
 
 impl UninitializedOptimizerConfig {
     // TODO: add a provider_types argument as needed
     async fn load(self) -> Result<OptimizerConfig, Error> {
         Ok(match self {
+            UninitializedOptimizerConfig::Dicl(config) => OptimizerConfig::Dicl(config.load()?),
             UninitializedOptimizerConfig::OpenAISFT(config) => {
                 OptimizerConfig::OpenAISFT(config.load()?)
             }
@@ -330,7 +386,7 @@ impl UninitializedOptimizerConfig {
                 OptimizerConfig::GCPVertexGeminiSFT(Box::new(config.load().await?))
             }
             UninitializedOptimizerConfig::TogetherSFT(config) => {
-                OptimizerConfig::TogetherSFT(config.load()?)
+                OptimizerConfig::TogetherSFT(Box::new(config.load()?))
             }
         })
     }
