@@ -13,7 +13,10 @@ use uuid::Uuid;
 use crate::inference::InferenceProvider;
 
 use crate::cache::ModelProviderRequest;
-use crate::embeddings::{EmbeddingProvider, EmbeddingProviderResponse, EmbeddingRequest};
+use crate::embeddings::{
+    Embedding, EmbeddingProvider, EmbeddingProviderRequestInfo, EmbeddingProviderResponse,
+    EmbeddingRequest,
+};
 use crate::endpoints::inference::InferenceCredentials;
 use crate::error::{Error, ErrorDetails};
 use crate::inference::types::batch::PollBatchInferenceResponse;
@@ -230,7 +233,7 @@ pub static DUMMY_STREAMING_TOOL_RESPONSE: [&str; 5] = [
 ];
 
 pub static DUMMY_STREAMING_JSON_RESPONSE: [&str; 5] =
-    [r#"{"name""#, r#":"John""#, r#","age""#, r#":30"#, r#"}"#];
+    [r#"{"name""#, r#":"John""#, r#","age""#, r":30", r"}"];
 
 pub static DUMMY_RAW_REQUEST: &str = "raw request";
 
@@ -333,6 +336,11 @@ impl InferenceProvider for DummyProvider {
                 arguments: serde_json::to_string(&*DUMMY_TOOL_RESPONSE).unwrap(),
                 id: "0".to_string(),
             })],
+            "invalid_tool_arguments" => vec![ContentBlockOutput::ToolCall(ToolCall {
+                name: "get_temperature".to_string(),
+                arguments: "Not valid 'JSON'".to_string(),
+                id: "0".to_string(),
+            })],
             "reasoner" => vec![
                 ContentBlockOutput::Thought(Thought {
                     text: Some("hmmm".to_string()),
@@ -750,6 +758,7 @@ impl EmbeddingProvider for DummyProvider {
         request: &EmbeddingRequest,
         _http_client: &reqwest::Client,
         _dynamic_api_keys: &InferenceCredentials,
+        _model_provider_data: &EmbeddingProviderRequestInfo,
     ) -> Result<EmbeddingProviderResponse, Error> {
         if self.model_name.starts_with("error") {
             return Err(ErrorDetails::InferenceClient {
@@ -764,9 +773,12 @@ impl EmbeddingProvider for DummyProvider {
             }
             .into());
         }
+        if self.model_name.contains("slow") {
+            tokio::time::sleep(Duration::from_secs(30)).await;
+        }
         let id = Uuid::now_v7();
         let created = current_timestamp();
-        let embedding = vec![0.0; 1536];
+        let embeddings = vec![Embedding::Float(vec![0.0; 1536]); request.input.num_inputs()];
         let raw_request = DUMMY_RAW_REQUEST.to_string();
         let raw_response = DUMMY_RAW_REQUEST.to_string();
         let usage = Usage {
@@ -778,8 +790,8 @@ impl EmbeddingProvider for DummyProvider {
         };
         Ok(EmbeddingProviderResponse {
             id,
-            input: request.input.to_string(),
-            embedding,
+            input: request.input.clone(),
+            embeddings,
             created,
             raw_request,
             raw_response,
