@@ -11,7 +11,7 @@ use tensorzero::{
     DynamicEvaluationRunParams, FeedbackParams, InferenceOutput, Role,
 };
 use tensorzero_core::{
-    clickhouse::test_helpers::{
+    db::clickhouse::test_helpers::{
         get_clickhouse, select_chat_inference_clickhouse, select_dynamic_evaluation_run_clickhouse,
         select_dynamic_evaluation_run_episode_clickhouse,
     },
@@ -35,6 +35,8 @@ async fn test_dynamic_evaluation() {
     };
     let dynamic_evaluation_info = client.dynamic_evaluation_run(params).await.unwrap();
     let run_id = dynamic_evaluation_info.run_id;
+    // Sleep for 200ms to allow time for data to be inserted into ClickHouse (trailing writes from API)
+    tokio::time::sleep(Duration::from_millis(200)).await;
     let clickhouse = get_clickhouse().await;
     let run_row = select_dynamic_evaluation_run_clickhouse(&clickhouse, run_id)
         .await
@@ -90,6 +92,7 @@ async fn test_dynamic_evaluation() {
         } else {
             panic!("Expected a non-streaming response");
         };
+        tokio::time::sleep(Duration::from_millis(500)).await;
         // We won't test the output here but will grab from ClickHouse so we can check the variant name
         // and tags
         let clickhouse = get_clickhouse().await;
@@ -217,6 +220,8 @@ async fn test_dynamic_evaluation_other_function() {
     };
     let result = client.dynamic_evaluation_run(params).await.unwrap();
     let run_id = result.run_id;
+    // Sleep for 200ms to allow time for data to be inserted into ClickHouse (trailing writes from API)
+    tokio::time::sleep(Duration::from_millis(200)).await;
     let clickhouse = get_clickhouse().await;
     let run_row = select_dynamic_evaluation_run_clickhouse(&clickhouse, run_id)
         .await
@@ -261,6 +266,7 @@ async fn test_dynamic_evaluation_other_function() {
     };
     // We won't test the output here but will grab from ClickHouse so we can check the variant name
     // and tags
+    tokio::time::sleep(Duration::from_millis(200)).await;
     let clickhouse = get_clickhouse().await;
     let result = select_chat_inference_clickhouse(&clickhouse, response.inference_id())
         .await
@@ -287,6 +293,8 @@ async fn test_dynamic_evaluation_variant_error() {
     };
     let result = client.dynamic_evaluation_run(params).await.unwrap();
     let run_id = result.run_id;
+    // Sleep for 200ms to allow time for data to be inserted into ClickHouse (trailing writes from API)
+    tokio::time::sleep(Duration::from_millis(200)).await;
     let clickhouse = get_clickhouse().await;
     let run_row = select_dynamic_evaluation_run_clickhouse(&clickhouse, run_id)
         .await
@@ -341,6 +349,8 @@ async fn test_dynamic_evaluation_override_variant_tags() {
     };
     let result = client.dynamic_evaluation_run(params).await.unwrap();
     let run_id = result.run_id;
+    // Sleep for 200ms to allow time for data to be inserted into ClickHouse (trailing writes from API)
+    tokio::time::sleep(Duration::from_millis(200)).await;
     let clickhouse = get_clickhouse().await;
     let run_row = select_dynamic_evaluation_run_clickhouse(&clickhouse, run_id)
         .await
@@ -384,6 +394,8 @@ async fn test_dynamic_evaluation_override_variant_tags() {
     } else {
         panic!("Expected a non-streaming response");
     };
+    // Sleep for 200ms to allow time for data to be inserted into ClickHouse (trailing writes from API)
+    tokio::time::sleep(Duration::from_millis(200)).await;
     // We won't test the output here but will grab from ClickHouse so we can check the variant name
     // and tags
     let clickhouse = get_clickhouse().await;
