@@ -3,7 +3,7 @@ use std::path::PathBuf;
 use reqwest::{Client, StatusCode};
 use serde_json::{json, Value};
 use tensorzero_core::{
-    clickhouse::test_helpers::{
+    db::clickhouse::test_helpers::{
         select_feedback_clickhouse, select_feedback_tags_clickhouse,
         select_human_static_evaluation_feedback_clickhouse,
     },
@@ -14,7 +14,7 @@ use tracing_test::traced_test;
 use uuid::Uuid;
 
 use crate::common::get_gateway_endpoint;
-use tensorzero_core::clickhouse::test_helpers::{get_clickhouse, CLICKHOUSE_URL};
+use tensorzero_core::db::clickhouse::test_helpers::{get_clickhouse, CLICKHOUSE_URL};
 
 // TODO: make these write human feedback and make sure this is writing correctly.
 
@@ -26,6 +26,7 @@ async fn make_embedded_gateway() -> tensorzero::Client {
         clickhouse_url: Some(CLICKHOUSE_URL.clone()),
         timeout: None,
         verify_credentials: true,
+        allow_batch_writes: true,
     })
     .build()
     .await
@@ -129,6 +130,7 @@ async fn e2e_test_comment_human_feedback() {
     let feedback_id = Uuid::parse_str(feedback_id.as_str().unwrap()).unwrap();
 
     // Check ClickHouse
+    sleep(Duration::from_millis(200)).await;
     let clickhouse = get_clickhouse().await;
     let result = select_feedback_clickhouse(&clickhouse, "CommentFeedback", feedback_id)
         .await
